<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>AudioItem</name>
    <message>
        <location filename="../../src/timeline/widgets/AudioItem.cc" line="+125"/>
        <source>Save File</source>
        <translation>Datei speichern</translation>
    </message>
</context>
<context>
    <name>DateSeparator</name>
    <message>
        <location filename="../../src/timeline/TimelineView.cc" line="+54"/>
        <source>Today</source>
        <translation>Heute</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Yesterday</source>
        <translation>Gestern</translation>
    </message>
</context>
<context>
    <name>EditModal</name>
    <message>
        <location filename="../../src/dialogs/RoomSettings.cpp" line="+34"/>
        <source>APPLY</source>
        <translation>EINSETZEN</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>CANCEL</source>
        <translation>ABBRECHEN</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Name</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Topic</source>
        <translation>Thema</translation>
    </message>
</context>
<context>
    <name>FileItem</name>
    <message>
        <location filename="../../src/timeline/widgets/FileItem.cc" line="+111"/>
        <source>Save File</source>
        <translation>Datei speichern</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <location filename="../../src/timeline/widgets/ImageItem.cc" line="+229"/>
        <source>Save image</source>
        <translation>Bild speichern</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <location filename="../../src/LoginPage.cc" line="+79"/>
        <source>Matrix ID</source>
        <translation>Matrix ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>e.g @joe:matrix.org</source>
        <translation>z.B. @joe:matrix.org</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>LOGIN</source>
        <translation>ANMELDEN</translation>
    </message>
    <message>
        <location line="+128"/>
        <source>Empty password</source>
        <translation>Leeres Passwort</translation>
    </message>
</context>
<context>
    <name>MatrixClient</name>
    <message>
        <location filename="../../src/MatrixClient.cc" line="+164"/>
        <source>Wrong username or password</source>
        <translation>Falscher Nutzername oder Passwort</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Login endpoint was not found on the server</source>
        <translation>Login-Endpunkt wurde auf dem Server nicht gefunden</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>An unknown error occured. Please try again.</source>
        <translation>Ein unbekannter Fehler trat auf. Bitte erneut versuchen.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Malformed response. Possibly not a Matrix server</source>
        <translation>Ungewöhnliche Antwort. Vielleicht kein Matrix-Server</translation>
    </message>
</context>
<context>
    <name>MemberList</name>
    <message>
        <location filename="../../src/dialogs/MemberList.cpp" line="+79"/>
        <source>Room members</source>
        <translation>Teilnehmer Liste</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>SHOW MORE</source>
        <translation>MEHR ZEIGEN</translation>
    </message>
</context>
<context>
    <name>QuickSwitcher</name>
    <message>
        <location filename="../../src/QuickSwitcher.cc" line="+70"/>
        <source>Search for a room...</source>
        <translation>Raum suchen...</translation>
    </message>
</context>
<context>
    <name>RegisterPage</name>
    <message>
        <location filename="../../src/RegisterPage.cc" line="+76"/>
        <source>Username</source>
        <translation>Nutzername</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Password confirmation</source>
        <translation>Passwort-Bestätigung</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Home Server</source>
        <translation>Heimserver</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>REGISTER</source>
        <translation>REGISTRIEREN</translation>
    </message>
    <message>
        <location line="+76"/>
        <source>Invalid username</source>
        <translation>Ungültiger Nutzername</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Password is not long enough (min 8 chars)</source>
        <translation>Passwort nicht lang genug (mind. 8 Zeichen)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Passwords don&apos;t match</source>
        <translation>Passwörter stimmen nicht überein</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Invalid server name</source>
        <translation>Ungültiger Server-Name</translation>
    </message>
</context>
<context>
    <name>RoomInfoListItem</name>
    <message>
        <location filename="../../src/RoomInfoListItem.cc" line="+78"/>
        <source>Leave room</source>
        <translation>Raum verlassen</translation>
    </message>
    <message>
        <location line="+153"/>
        <source>Accept</source>
        <translation>Akzeptieren </translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decline</source>
        <translation>Untersagen</translation>
    </message>
</context>
<context>
    <name>SideBarActions</name>
    <message>
        <location filename="../../src/SideBarActions.cc" line="+36"/>
        <source>Create new room</source>
        <translation>Neuen Raum erstellen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Join a room</source>
        <translation>In Raum eintreten</translation>
    </message>
</context>
<context>
    <name>TextInputWidget</name>
    <message>
        <location filename="../../src/TextInputWidget.cc" line="+445"/>
        <source>Write a message...</source>
        <translation>Schreibe eine Nachricht...</translation>
    </message>
    <message>
        <location line="+108"/>
        <source>Select a file</source>
        <translation>Datei auswählen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>All Files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
</context>
<context>
    <name>TopRoomBar</name>
    <message>
        <location filename="../../src/TopRoomBar.cc" line="+87"/>
        <source>Invite users</source>
        <translation>Nutzer einladen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Members</source>
        <translation>Teilnehmer</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Leave room</source>
        <translation>Raum verlassen</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../../src/TrayIcon.cc" line="+116"/>
        <source>Show</source>
        <translation>Zeigen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Quit</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>TypingDisplay</name>
    <message>
        <location filename="../../src/TypingDisplay.cc" line="+26"/>
        <source> is typing</source>
        <translation> tippt ein</translation>
    </message>
    <message>
        <location line="+2"/>
        <source> are typing</source>
        <translation> tippen ein</translation>
    </message>
</context>
<context>
    <name>UserSettingsPage</name>
    <message>
        <location filename="../../src/UserSettingsPage.cc" line="+121"/>
        <source>User Settings</source>
        <translation>Nutzer Einstellungen</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Minimize to tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Start in tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Re-order rooms based on activity</source>
        <translation>Räume nach Aktivität sortieren</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Group&apos;s sidebar</source>
        <translation>Gruppen-Seiten-Panel</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Typing notifications</source>
        <translation>Schreibbenachrichtigungen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Read receipts</source>
        <translation>Lesebestätigungen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>GENERAL</source>
        <translation>ALLGEMEINES</translation>
    </message>
</context>
<context>
    <name>WelcomePage</name>
    <message>
        <location filename="../../src/WelcomePage.cc" line="+44"/>
        <source>Welcome to nheko! The desktop client for the Matrix protocol.</source>
        <translation>Willkommen bei nheko, dem Desktop-Client für das Matrix-Protokoll.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enjoy your stay!</source>
        <translation>Genieße deinen Aufenthalt!</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>REGISTER</source>
        <translation>REGISTRIEREN</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>LOGIN</source>
        <translation>ANMELDEN</translation>
    </message>
</context>
<context>
    <name>dialogs::CreateRoom</name>
    <message>
        <location filename="../../src/dialogs/CreateRoom.cc" line="+32"/>
        <source>CANCEL</source>
        <translation>ABBRECHEN</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Name</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Topic</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alias</source>
        <translation>Alias</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Room Visibility</source>
        <translation>Raumsichtbarkeit</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Room Preset</source>
        <translation>Raumvorlage</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Direct Chat</source>
        <translation>Direkter Chat</translation>
    </message>
</context>
<context>
    <name>dialogs::InviteUsers</name>
    <message>
        <location filename="../../src/dialogs/InviteUsers.cc" line="+36"/>
        <source>CANCEL</source>
        <translation>ABBRECHEN</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>User ID to invite</source>
        <translation>Nutzer ID, die eingeladen werden soll</translation>
    </message>
</context>
<context>
    <name>dialogs::JoinRoom</name>
    <message>
        <location filename="../../src/dialogs/JoinRoom.cc" line="+30"/>
        <source>CANCEL</source>
        <translation>ABBRECHEN</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Room ID or alias</source>
        <translation>Raum-ID oder -Alias</translation>
    </message>
</context>
<context>
    <name>dialogs::LeaveRoom</name>
    <message>
        <location filename="../../src/dialogs/LeaveRoom.cc" line="+29"/>
        <source>CANCEL</source>
        <translation>ABBRECHEN</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Are you sure you want to leave?</source>
        <translation>Bist du sicher, dass du den Raum verlassen willst?</translation>
    </message>
</context>
<context>
    <name>dialogs::Logout</name>
    <message>
        <location filename="../../src/dialogs/Logout.cc" line="+47"/>
        <source>CANCEL</source>
        <translation>ABBRECHEN</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Logout. Are you sure?</source>
        <translation>Bist du dir sicher, dass du dich abmelden willst?</translation>
    </message>
</context>
<context>
    <name>dialogs::PreviewUploadOverlay</name>
    <message>
        <location filename="../../src/dialogs/PreviewUploadOverlay.cc" line="+41"/>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Media type: %1
Media size: %2
</source>
        <translation>Medien-Typ: %1
Medien-Größe: %2
</translation>
    </message>
</context>
<context>
    <name>dialogs::ReCaptcha</name>
    <message>
        <location filename="../../src/dialogs/ReCaptcha.cpp" line="+34"/>
        <source>CONFIRM</source>
        <translation>BESTÄTIGEN</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>CANCEL</source>
        <translation>ABBRECHEN</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Solve the reCAPTCHA and press the confirm button</source>
        <translation>Löse das reCAPTCHA und drücke den &quot;Bestätigen&quot;-Knopf</translation>
    </message>
</context>
<context>
    <name>dialogs::ReadReceipts</name>
    <message>
        <location filename="../../src/dialogs/ReadReceipts.cc" line="+98"/>
        <source>Read receipts</source>
        <translation>Lesebestätigungen</translation>
    </message>
</context>
<context>
    <name>dialogs::RoomSettings</name>
    <message>
        <location filename="../../src/dialogs/RoomSettings.cpp" line="+147"/>
        <source>CANCEL</source>
        <translation>ABBRECHEN</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Muted</source>
        <translation>Stumm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mentions only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All messages</source>
        <translation>Alle Nachrichten</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Room access</source>
        <translation>Raum Zugang</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Anyone and guests</source>
        <translation>Alle, denen der Raum-Link bekannt ist (auch Gäste)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Anyone</source>
        <translation>Alle, denen der Raum-Link bekannt ist (ausgenommen Gäste)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Invited users</source>
        <translation>Nur Personen, die eingeladen wurden</translation>
    </message>
</context>
<context>
    <name>emoji::Panel</name>
    <message>
        <location filename="../../src/emoji/Panel.cc" line="+125"/>
        <source>Smileys &amp; People</source>
        <translation>Smileys &amp; Personen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Animals &amp; Nature</source>
        <translation>Tiere &amp; Natur</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Food &amp; Drink</source>
        <translation>Essen &amp; Trinken</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Activity</source>
        <translation>Aktivitäten</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Travel &amp; Places</source>
        <translation>Reisen &amp; Orte</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Objects</source>
        <translation>Objekte</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Symbols</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Flags</source>
        <translation>Flaggen</translation>
    </message>
</context>
</TS>
